@@ -21,11 +21,41 @@
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-from spoon import Serial, serialprop, lazyprop
-from spoon import SPOONLINKMSG_TAG as __SPOONLINKMSG_TAG__, SPOONNETMSG_TAG as __SPOONNETMSG_TAG__
+__author__ = "Matt Sullivan <matts@zarrf.com>"
+__date__ = "22 Nov 2006"
+__version__ = "0.1.1"
+__version_info__ = (0,1,1)
+__license__ = "MIT/X Consortium"
+
+
+from spooncore import Serial, serialprop, lazyprop
+from spooncore import SPOONLINKMSG_TAG as __SPOONLINKMSG_TAG__, SPOONNETMSG_TAG as __SPOONNETMSG_TAG__
 from spoonstream import SpoonStream
-from NullLogger import NullLogger
+from nulllogger import NullLogger
 from objTypes import *
 
+for x in [Serial, serialprop, lazyprop, SpoonStream, NullLogger]:
+    x.__module__ = "spoon"
+
+import messaging
+import routing
+import transports
+import ber
+
+messaging.__module__ = "spoon"
+routing.__module__ = "spoon"
+transports.__module__ = "spoon"
+ber.__module__ = "spoon"
+
+__all__ = ["Serial", 
+           "serialprop", 
+           "lazyprop",
+           "SpoonStream",
+           "NullLogger",
+           "messaging",
+           "routing",
+           "transports",
+           "ber"]
+
+
 
-import messaging, routing, transports, ber
