@@ -21,5 +21,10 @@
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-from decorators import handleMsg
-from messaging import Messaging, SingletonMessaging
+from decorators import receive, handleMsg
+from messagingcore import Messaging, SingletonMessaging, send
+
+for x in [receive, handleMsg, Messaging, SingletonMessaging, send]:
+    x.__module__ = "spoon.messaging"
+
+__all__ = ["receive", "handleMsg", "Messaging", "SingletonMessaging", "send"]
\ No newline at end of file
