@@ -21,6 +21,11 @@
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-from MeshRouter import NetMessage, RoutingProtocolError, NodeUnreachable
-from MeshRouter import MeshRouter
 
+from meshrouter import NetMessage, RoutingProtocolError, NodeUnreachable
+from meshrouter import MeshRouter
+
+#for x in [NetMessage, RoutingProtocolError, NodeUnreachable, MeshRouter]:
+#    x.__module__ = "spoon.routing"
+    
+__all__= ["NetMessage", "RoutingProtocolError", "NodeUnreachable", "MeshRouter"]
\ No newline at end of file
