@@ -20,6 +20,18 @@
 # TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
+"""
+Subpackage for link related objects.  These are used for interaction between two nodes directly, and
+for creating connections.
+"""
+from transporthub import TransportHub, SpoonRPCHello, TransportException, LinkMessage
+from spoontransport import SpoonTransport
 
-from transports import TransportHub, SpoonRPCHello, TransportException, LinkMessage
-from SpoonTransport import SpoonTransport
+for x in [TransportHub, SpoonRPCHello, TransportException, LinkMessage, SpoonTransport]:
+    x.__module__ = "spoon.transports"
+    
+__all__ = ["TransportHub", 
+           "SpoonRPCHello", 
+           "TransportException",
+           "LinkMessage",
+           "SpoonTransport"]
\ No newline at end of file
